Example Zoidberg grid generation
================================

Here are several examples of generating grids using Zoidberg for simulations
using the FCI parallel transform:

- `example-straight-stellarator.py`: A "straight stellarator", a rotating
  ellipse stellarator without curvature
- `straight-stellarator-curvilinear.py`: A straight stellarator but based on
  curvilinear grids
- `tokamak.py`: A tokamak grid generated from an EFIT "geqdsk" file

The remaining files demonstrate some of the plotting capabilities of Zoidberg:

- `field_line.py`: 3D plots of magnetic field lines
- `poincare.py`: A Poincaré plot of a straight stellarator
